@@ -1,5 +1,5 @@
 /*
- * Copyright 2024 Bytes & Brains
+ * Copyright 2023 Zacharias Knudsen
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,17 +15,4 @@
  */
 
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
-\echo Use "ALTER EXTENSION h3 UPDATE TO '4.1.4'" to load this file. \quit
-
-CREATE OR REPLACE FUNCTION
-    h3index_recv(internal) RETURNS h3index
-AS 'h3' LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
-
-CREATE OR REPLACE FUNCTION
-    h3index_send(h3index) RETURNS bytea
-AS 'h3' LANGUAGE C IMMUTABLE STRICT PARALLEL SAFE;
-
-ALTER TYPE h3index SET (
-    RECEIVE = h3index_recv,
-    SEND    = h3index_send
-);
+\echo Use "ALTER EXTENSION h3 UPDATE TO '4.1.2'" to load this file. \quit
